{ config, pkgs, ... }:

{
  imports = [
    ./home-modules/emacs.nix
    ./home-modules/fetch.nix
  ];

  nixpkgs.config.allowUnfree = true;
  home.username = "svante";
  home.homeDirectory = "/home/svante";
  home.stateVersion = "23.11"; 

  home.packages = with pkgs; [
    fortune
    mako
    kdePackages.kalgebra
    libreoffice
    htop
    ripgrep
    xwaylandvideobridge
    qtpass
    pipewire
    jdk21
    wireplumber
    xdg-desktop-portal-hyprland
    qt6.qtwayland
    libsForQt5.qt5.qtwayland
    ccls
    clang
    obs-studio
    prismlauncher
    prusa-slicer
    freecad
    direnv
    easyeffects
    tmux
    kicad
    spotify
    arduino-ide
    gimp
    feh
    distrobox
    dig
    socat
    steam
    libei
    hyprlock
    waypaper
  ];

  programs.ncspot = {
    enable = true;
    settings = {
      notify = true;
    };
  };

  services.mako = {
    enable = true;
    backgroundColor = "#1e1e2ee0";
    borderRadius = 10;
    icons = false;
    defaultTimeout = 3000;
  };

  programs.thunderbird.enable = true;
  programs.thunderbird.profiles = { };

  home.file = {
	".config/fuzzel".source = dotfiles/fuzzel;
	".config/hypr".source = dotfiles/hypr;
	".config/kitty".source = dotfiles/kitty;
	".config/nvim/lua/vanten".source = dotfiles/nvim;
	".config/waybar".source = dotfiles/waybar;
	".config/zsh".source = dotfiles/zsh;
	".config/local".source = dotfiles/local;
	"scripts".source = dotfiles/scripts;
	".zshrc".source = dotfiles/zshrc;
	".wallpapers".source = dotfiles/wallpapers;
  };

  home.sessionVariables = { };

  programs.home-manager.enable = true;
}
